@@ -2,7 +2,7 @@
 from typing import Any, List, Mapping, Optional, Set, Tuple
 
 from apgw.constraint import (BinaryConstraint, Constraints, DictConstraint,
-                             Literal, TextConstraint)
+                             GroupConstraint, Literal, TextConstraint)
 from apgw.types import SQL, InsertAssignments, LimitOffset, Record
 from apgw.util import constraint_list_to_sql
 
@@ -41,7 +41,7 @@ def constraints_to_sql(
     paren: bool = True,
     joiner: str = " and ",
     offset: int = 0,
-    handle_null: bool = True
+    handle_null: bool = True,
 ) -> SQL:
     """This methods converts a constraints object to SQL and params.
 
@@ -71,6 +71,10 @@ def constraints_to_sql(
         constraint_list = constraints
     elif isinstance(constraints, BinaryConstraint):
         constraint_list = [constraints]
+    elif isinstance(constraints, GroupConstraint):
+        return group_constraint_to_sql(
+            constraints, offset=offset, handle_null=handle_null
+        )
     else:
         raise Exception("Invalid constraint type")
 
@@ -83,13 +87,41 @@ def constraints_to_sql(
     )
 
 
+def group_constraint_to_sql(group: GroupConstraint, *, offset: int, handle_null) -> SQL:
+    """This method converts a GroupConstraint object to SQL and params.
+
+    :param group: the group constraint
+    :param offset: the offset for parameter placeholders
+    :param handle_null: if True, the constraint values of None will be handled specially
+    """
+    sql = ""
+    params = []
+    for constraint in group.constraints:
+        (part_sql, part_params) = constraints_to_sql(
+            constraint,
+            paren=False,
+            joiner=group.joiner,
+            offset=offset,
+            handle_null=handle_null,
+        )
+        offset += len(part_params)
+        params.extend(part_params)
+        if part_sql:
+            part_sql = "(" + part_sql + ")"
+            if not sql:
+                sql = part_sql
+            else:
+                sql = f"{sql} {group.joiner} {part_sql}"
+    return (sql, params)
+
+
 def select_sql(
     table_name: str,
     constraints: Constraints = None,
     *,
     columns: str = "*",
     order_by: str = None,
-    limit: LimitOffset = None
+    limit: LimitOffset = None,
 ) -> SQL:
     """Generates a select statement.
 
@@ -165,7 +197,7 @@ def update_sql(
     constraints: Constraints = None,
     *,
     timestamp_col: Optional[str] = "updated_at",
-    returning: str = None
+    returning: str = None,
 ) -> SQL:
     """Generates an update statement.
 
