@@ -26,9 +26,16 @@ class Literal:
     value: str
 
 
+@dataclass(frozen=True)
+class GroupConstraint:
+    joiner: str
+    constraints: List[Union["GroupConstraint", BinaryConstraint]]
+
+
 Constraints = Union[
     BinaryConstraint,
     DictConstraint,
     List[BinaryConstraint],
     TextConstraint,
+    GroupConstraint,
 ]
